@@ -12,20 +12,22 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#![no_std]
 #![warn(missing_docs)]
 
 //! `std:ops` traits for `Future`
 //!
 //! This crate provides a way to use
 //! [some `std::ops` traits](#supported-stdops-traits) with [futures](Future).
-//! To be able to use a [`std::ops`] trait with a `Future`, first you need to
-//! wrap the `Future` with [`Async`] using [`async_ops::on`](crate::on). Then,
-//! as long the `Future::Output` type implements a supported `std::ops` trait,
-//! then the same `std::ops` trait will be implemented by the `Async` instance.
+//! To be able to use a [`std::ops`](core::ops) trait with a `Future`, first you
+//! need to wrap the `Future` with [`Async`] using [`async_ops::on`](crate::on).
+//! Then, as long the `Future::Output` type implements a supported `std::ops`
+//! trait, then the same `std::ops` trait will be implemented by the `Async`
+//! instance.
 //!
 //! Another option is to wrap a `Future` with `Async` using
-//! [`async_ops::assignable`](crate::assignable) to enable usage of the `Assign`
-//! variants of `std::ops` traits on the `Future`.
+//! [`assignable!`] to enable usage of the `Assign` variants of `std::ops`
+//! traits on the `Future`.
 //!
 //! # Example
 //!
@@ -33,7 +35,7 @@
 //! through `std::ops`. For example, adding to numbers might look like this:
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! // Immediately returning a number is done for simplicity and production code
 //! // wouldn't just immediately return a value.
@@ -51,11 +53,11 @@
 //! like this:
 //!
 //! ```rust
-//! # use futures::executor::block_on;
+//! # use futures_executor::block_on;
 //! # let a = async { 40 };
 //! # let b = async { 2 };
 //!
-//! use futures::join;
+//! use futures_util::join;
 //!
 //! let result = async {
 //!   let (a, b) = join!(a, b);
@@ -69,7 +71,7 @@
 //! above example in one line:
 //!
 //! ```rust
-//! # use futures::executor::block_on;
+//! # use futures_executor::block_on;
 //! # let a = async { 40 };
 //! # let b = async { 2 };
 //!
@@ -91,7 +93,7 @@
 //! `Async<impl Future<Output = <Future::Output as Add<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 40 };
 //! let b = async { 2 };
@@ -109,13 +111,13 @@
 //! `Add<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 40 };
 //! let b = async { 2 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a += b;
 //!   a.await
 //! };
@@ -131,7 +133,7 @@
 //! `Async<impl Future<Output = <Future::Output as BitAnd<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 110 };
 //! let b = async { 59 };
@@ -149,13 +151,13 @@
 //! the `Future::Output` type to implement `BitAnd<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 110 };
 //! let b = async { 59 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a &= b;
 //!   a.await
 //! };
@@ -171,7 +173,7 @@
 //! `Async<impl Future<Output = <Future::Output as BitOr<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 40 };
 //! let b = async { 10 };
@@ -189,13 +191,13 @@
 //! the `Future::Output` type to implement `BitOr<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 40 };
 //! let b = async { 10 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a |= b;
 //!   a.await
 //! };
@@ -211,7 +213,7 @@
 //! `Async<impl Future<Output = <Future::Output as BitXor<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 38 };
 //! let b = async { 12 };
@@ -229,13 +231,13 @@
 //! the `Future::Output` type to implement `BitXor<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 38 };
 //! let b = async { 12 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a ^= b;
 //!   a.await
 //! };
@@ -251,7 +253,7 @@
 //! `Async<impl Future<Output = <Future::Output as Div<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 84 };
 //! let b = async { 2 };
@@ -269,13 +271,13 @@
 //! `Div<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 84 };
 //! let b = async { 2 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a /= b;
 //!   a.await
 //! };
@@ -291,7 +293,7 @@
 //! `Async<impl Future<Output = <Future::Output as Mul<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 21 };
 //! let b = async { 2 };
@@ -309,13 +311,13 @@
 //! `Mul<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 21 };
 //! let b = async { 2 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a *= b;
 //!   a.await
 //! };
@@ -330,7 +332,7 @@
 //! `Async<impl Future<Output = <Future::Output as Neg>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { -42 };
 //!
@@ -346,7 +348,7 @@
 //! `Async<impl Future<Output = <Future::Output as Not>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 213_u8 };
 //!
@@ -363,7 +365,7 @@
 //! `Async<impl Future<Output = <Future::Output as Rem<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 42 };
 //! let b = async { 5 };
@@ -381,13 +383,13 @@
 //! `Rem<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 42 };
 //! let b = async { 5 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a %= b;
 //!   a.await
 //! };
@@ -403,7 +405,7 @@
 //! `Async<impl Future<Output = <Future::Output as Shl<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 21 };
 //! let b = async { 1 };
@@ -421,13 +423,13 @@
 //! `Shl<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 21 };
 //! let b = async { 1 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a <<= b;
 //!   a.await
 //! };
@@ -443,7 +445,7 @@
 //! `Async<impl Future<Output = <Future::Output as Shr<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 168 };
 //! let b = async { 2 };
@@ -461,13 +463,13 @@
 //! `Shr<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 168 };
 //! let b = async { 2 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a >>= b;
 //!   a.await
 //! };
@@ -483,7 +485,7 @@
 //! `Async<impl Future<Output = <Future::Output as Sub<Rhs::Output>>::Output>>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 44 };
 //! let b = async { 2 };
@@ -501,13 +503,13 @@
 //! `Sub<Rhs::Output>`.
 //!
 //! ```rust
-//! use futures::executor::block_on;
+//! use futures_executor::block_on;
 //!
 //! let a = async { 44 };
 //! let b = async { 2 };
 //!
 //! let result = async {
-//!   let mut a = async_ops::assignable(a);
+//!   async_ops::assignable!(a);
 //!   a -= b;
 //!   a.await
 //! };
@@ -515,11 +517,13 @@
 //! assert_eq!(42, block_on(result));
 //! ```
 
+extern crate alloc;
+
 mod ops;
 
-use std::future::Future;
-use std::pin::Pin;
-use std::task::{Context, Poll};
+use core::future::Future;
+use core::pin::Pin;
+use core::task::{Context, Poll};
 
 use futures::future::BoxFuture;
 use pin_project_lite::pin_project;
@@ -534,7 +538,7 @@ pub use ops::{
 /// # Example
 ///
 /// ```rust
-/// use futures::executor::block_on;
+/// use futures_executor::block_on;
 ///
 /// let a = async { 40 };
 /// let b = async { 2 };
@@ -547,15 +551,43 @@ pub fn on<Fut: Future>(future: Fut) -> Async<Fut> {
   Async { future }
 }
 
-/// Wraps the given [`Future`] with [`Async`] that can be used with the `Assign`
-/// variants of [`std::ops`] traits.
+/// Wraps the given [`Future`] with [`Async`] so that the result can be used
+/// with the `Assign` variants of [`std::ops`](core::ops) traits.
 ///
 /// See also [`Async::assignable`].
 ///
 /// # Example
 ///
 /// ```rust
-/// use futures::executor::block_on;
+/// use futures_executor::block_on;
+///
+/// let a = async { 40 };
+/// let b = async { 2 };
+///
+/// let result = async {
+///   async_ops::assignable!(a);
+///   a += b;
+///   a.await
+/// };
+///
+/// assert_eq!(42, block_on(result));
+/// ```
+#[macro_export]
+macro_rules! assignable {
+  ($var:ident) => {
+    let mut $var = $crate::assignable($var);
+  };
+}
+
+/// Wraps the given [`Future`] with [`Async`] so that the result can be used
+/// with the `Assign` variants of [`std::ops`](core::ops) traits.
+///
+/// Use [`assignable!`] and [`Async::assignable`] instead.
+///
+/// # Example
+///
+/// ```rust
+/// use futures_executor::block_on;
 ///
 /// let a = async { 40 };
 /// let b = async { 2 };
@@ -568,14 +600,18 @@ pub fn on<Fut: Future>(future: Fut) -> Async<Fut> {
 ///
 /// assert_eq!(42, block_on(result));
 /// ```
+#[deprecated(
+  since = "1.1.0",
+  note = "Use assignable! or Async::assignable instead."
+)]
 pub fn assignable<'a, Fut: Future + Send + 'a>(future: Fut) -> Async<BoxFuture<'a, Fut::Output>> {
   let future: BoxFuture<Fut::Output> = Assignable::from(future);
   Async { future }
 }
 
 pin_project! {
-  /// A wrapper class for a [`Future`] that enables usage of some [`std::ops`]
-  /// traits.
+  /// A wrapper class for a [`Future`] that enables usage of some
+  /// [`std::ops`](core::ops) traits.
   ///
   /// This struct will implement a supported `std::ops` trait when
   /// `<Fut as Future>::Output` type implements the same `std::ops` trait.
@@ -588,14 +624,15 @@ pin_project! {
 
 impl<Fut: Future> Async<Fut> {
   /// Wraps the inner [`Future`] in [`Async`] with the given `Assignable` type
-  /// so that it can be used with `Assign` variants of [`std::ops`] traits.
+  /// so that it can be used with `Assign` variants of [`std::ops`](core::ops)
+  /// traits.
   ///
-  /// See also [`async_ops::assignable`](crate::assignable).
+  /// See also [`assignable!`].
   ///
   /// # Example
   ///
   /// ```rust
-  /// use futures::executor::block_on;
+  /// use futures_executor::block_on;
   /// use futures::future::LocalBoxFuture;
   ///
   /// let a = async { 40 };
@@ -622,7 +659,7 @@ impl<Fut: Future> Async<Fut> {
   ///
   /// ```rust
   /// use std::future::{ready, Ready};
-  /// use futures::executor::block_on;
+  /// use futures_executor::block_on;
   /// use async_ops::Unary;
   ///
   /// struct Return42;
@@ -658,7 +695,7 @@ impl<Fut: Future> Async<Fut> {
   /// # Example
   ///
   /// ```rust
-  /// use futures::executor::block_on;
+  /// use futures_executor::block_on;
   /// use async_ops::Binary;
   ///
   /// struct ReturnRhs;
@@ -694,7 +731,7 @@ impl<Fut: Future> Async<Fut> {
   /// # Example
   ///
   /// ```rust
-  /// use futures::executor::block_on;
+  /// use futures_executor::block_on;
   /// use async_ops::Binary;
   ///
   /// struct ReturnRhs;
@@ -710,7 +747,7 @@ impl<Fut: Future> Async<Fut> {
   /// let b = async { 42 };
   ///
   /// let result = async {
-  ///   let mut a = async_ops::assignable(a);
+  ///   async_ops::assignable!(a);
   ///   a.op_assign(ReturnRhs, b);
   ///   a.await
   /// };
@@ -738,10 +775,10 @@ impl<Fut: Future> Future for Async<Fut> {
 mod tests {
   use super::*;
 
-  use std::cell::RefCell;
-  use std::rc::Rc;
+  use alloc::rc::Rc;
+  use core::cell::RefCell;
 
-  use futures::future::FutureExt;
+  use futures_util::future::FutureExt;
 
   pin_project! {
     #[derive(Default)]
